==> lego-web-0.0.48.tgz: package/src/server/index.js <==
const express = require('express')
const fs = require('fs')
const path = require('path')
const request = require('./utils/request')
const svgCaptcha = require('svg-captcha')
const session = require('express-session')
const cors = require('cors')
const Base64 = require('./utils/base64')

const app = express()

const maxAge = 30 * 60 * 1000
app.use(
  session({
    secret: 'lego-cms',
    name: 'sessionid',
    cookie: {
      maxAge: maxAge
    },
    resave: false,
    saveUninitialized: true,
    rolling: true
  })
)

var bodyParser = require('body-parser')

app.use(
  cors({
    origin: function(origin, callback) {
      callback(null, true)
    }
  })
)
app.use(bodyParser.json())

const pages = fs.readdirSync(path.join(__dirname, '../pages'))
const templates = {}
for (let pageFileName of pages) {
  let pageName = path.basename(pageFileName, '.js')
  try {
    templates[pageName] = fs.readFileSync(path.join(__dirname, `../../dist/${pageName}.html`)).toString()
  } catch (e) {}
}

app.get('/captcha', async (req, res) => {
  let captcha = svgCaptcha.create()
  req.session.captcha = captcha.text
  res.type('svg')
  res.status(200).send(captcha.data)
})

app.get('/checkLogin', async (req, res) => {
  res.json({
    userid: req.session.userid || ''
  })
})

app.get('/logout', async (req, res) => {
  delete req.session.userid
  res.json({})
})

app.post('/createSession', async (req, res) => {
  let { data, captcha } = req.body
  data.password = Base64.encode(data.password)
  if (req.session.captcha && captcha && captcha.toLowerCase() !== req.session.captcha.toLowerCase()) {
    return res.json({
      code: 1,
      error: 'B2C_LOGIN_VERCODERR'
    })
  }
  let result = await request({ req })
  if (!result.errorcode) {
    req.session.userid = result.userid
  }
  return res.json(result)
})

app.get('*', (req, res) => {
  res.send(templates.index)
})

module.exports = app

==> lego-web-0.0.55.tgz: package/src/server/index.js <==
const express = require('express')
const fs = require('fs')
const path = require('path')
const request = require('./utils/request')
const svgCaptcha = require('svg-captcha')
const session = require('express-session')
const cors = require('cors')
const Base64 = require('./utils/base64')

const app = express()

const maxAge = 30 * 60 * 1000
app.use(
  session({
    secret: 'lego-cms',
    name: 'sessionid',
    cookie: {
      maxAge: maxAge
    },
    resave: false,
    saveUninitialized: true,
    rolling: true
  })
)

var bodyParser = require('body-parser')

app.use(
  cors({
    origin: function(origin, callback) {
      callback(null, true)
    }
  })
)
app.use(bodyParser.json())

const pages = fs.readdirSync(path.join(__dirname, '../pages'))
const templates = {}
for (let pageFileName of pages) {
  let pageName = path.basename(pageFileName, '.js')
  try {
    templates[pageName] = fs.readFileSync(path.join(__dirname, `../../dist/${pageName}.html`)).toString()
  } catch (e) {}
}

app.get('/captcha', async (req, res) => {
  let captcha = svgCaptcha.create()
  req.session.captcha = captcha.text
  res.type('svg')
  res.status(200).send(captcha.data)
})

app.get('/checkLogin', async (req, res) => {
  res.json({
    userid: req.session.userid || ''
  })
})

app.get('/logout', async (req, res) => {
  delete req.session.userid
  res.json({})
})

app.post('/createSession', async (req, res) => {
  let { data, captcha } = req.body
  data.password = Base64.encode(data.password)
  if (!req.session.captcha || !captcha || captcha.toLowerCase() !== req.session.captcha.toLowerCase()) {
    return res.json({
      code: 1,
      error: 'B2C_LOGIN_VERCODERR'
    })
  }
  let result = await request({ req })
  if (!result.errorcode) {
    req.session.userid = result.userid
  }
  return res.json(result)
})

app.get('*', (req, res) => {
  res.send(templates.index)
})

module.exports = app
